﻿Public Class ViewerForm

    Const c_defPromptOnExit As Boolean = False

    Private m_strUser As String
    Private m_blnPromptOnExit As Boolean
    Private m_objPictureBackColor As Color

    Private Enum PrintDestination
        Printer = 0
        PrintPreview = 1
    End Enum


    Private Sub btnEnlarge_Click(sender As Object, e As EventArgs) Handles btnEnlarge.Click
        Me.Width = Me.Width + 20
        Me.Height = Me.Height + 20

    End Sub

    Private Sub btnShrink_Click(sender As Object, e As EventArgs) Handles btnShrink.Click
        Me.Width = Me.Width - 20
        Me.Height = Me.Height - 20

    End Sub

    Private Sub picShowPicture_MouseMove(sender As Object, e As MouseEventArgs) Handles picShowPicture.MouseMove
        lblX.Text = "X: " & e.X
        lblY.Text = "Y: " & e.Y

    End Sub

    Private Sub picShowPicture_MouseLeave(sender As Object, e As EventArgs) Handles picShowPicture.MouseLeave
        lblX.Text = ""
        lblY.Text = ""

    End Sub

    Private Sub ViewerForm_Load(sender As Object, e As EventArgs) Handles Me.Load
        lblX.Text = ""
        lblY.Text = ""

        LoadDefaults()

    End Sub

    Public Sub LoadDefaults()
        Const c_strKeyName As String =
                "HKEY_CURRENT_USER\Software\CleverSoftware\PictureViewer\"

        m_blnPromptOnExit = CBool(My.Computer.Registry.GetValue _
                (c_strKeyName, "PromptOnExit", "0"))

        If CStr(My.Computer.Registry.GetValue _
                (c_strKeyName, "BackColor", "Gray")) = "Gray" Then
            m_objPictureBackColor = System.Drawing.SystemColors.Control
        Else
            m_objPictureBackColor = System.Drawing.Color.White
        End If

        picShowPicture.BackColor = m_objPictureBackColor
        mnuConfirmOnExit.Checked = m_blnPromptOnExit

    End Sub


    Private Sub mnuOpenPicture_Click(sender As Object, e As EventArgs) Handles mnuOpenPicture.Click
        OpenPicture()

    End Sub

    Private Sub mnuConfirmOnExit_Click(sender As Object, e As EventArgs) Handles mnuConfirmOnExit.Click
        mnuConfirmOnExit.Checked = Not (mnuConfirmOnExit.Checked)
        m_blnPromptOnExit = mnuConfirmOnExit.Checked

    End Sub

    Private Sub mnuQuit_Click(sender As Object, e As EventArgs) Handles mnuQuit.Click
        Me.Close()

    End Sub

    Private Sub mnuDrawBorder_Click(sender As Object, e As EventArgs) Handles mnuDrawBorder.Click
        DrawBorder(picShowPicture)

    End Sub

    Private Sub mnuOptions_Click(sender As Object, e As EventArgs) Handles mnuOptions.Click
        OptionsForm.ShowDialog()

    End Sub

    Private Sub DrawBorderToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles DrawBorderToolStripMenuItem.Click
        Dim objGraphics As Graphics
        objGraphics = Me.CreateGraphics
        objGraphics.Clear(System.Drawing.SystemColors.Control)
        objGraphics.DrawRectangle(System.Drawing.Pens.Blue,
            picShowPicture.Left - 1,
            picShowPicture.Top - 1,
            picShowPicture.Width + 1, picShowPicture.Height + 1)
        objGraphics.Dispose()

    End Sub

    Private Sub tbbOpenPicture_Click(sender As Object, e As EventArgs) Handles tbbOpenPicture.Click
        OpenPicture()

    End Sub

    Private Sub tbbDrawBorder_Click(sender As Object, e As EventArgs) Handles tbbDrawBorder.Click
        DrawBorder(picShowPicture)

    End Sub

    Private Sub tbbOptions_Click(sender As Object, e As EventArgs) Handles tbbOptions.Click
        OptionsForm.ShowDialog()

    End Sub

    Private Sub ViewerForm_FormClosing(sender As Object, e As FormClosingEventArgs) Handles Me.FormClosing
        If m_blnPromptOnExit Then
            If MessageBox.Show("Close the Picture Viewer program?",
                    "Picture Viewer", MessageBoxButtons.YesNo,
                    MessageBoxIcon.Question) =
                    Windows.Forms.DialogResult.No Then
                e.Cancel = True
            End If
        End If

    End Sub

    Private Sub tbbGetFileAttributes_Click(sender As Object, e As EventArgs) Handles tbbGetFileAttributes.Click
        GetFileAttributes()

    End Sub

    Private Sub GetFileAttributes()
        Dim strProperties As String
        Dim lngAttributes As Long
        If ofdSelectPicture.FileName = "" Then Exit Sub
        ' Get the dates.
        strProperties = "Created: " &
            System.IO.File.GetCreationTime(ofdSelectPicture.FileName)
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Accessed: " &
            System.IO.File.GetLastAccessTime(ofdSelectPicture.FileName)
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Modified: " &
            System.IO.File.GetLastWriteTime(ofdSelectPicture.FileName)

        ' Get the file attributes.
        lngAttributes = System.IO.File.GetAttributes(ofdSelectPicture.FileName)
        ' Use a binary AND to extract the specific attributes.
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Normal: " &
            CBool(lngAttributes And IO.FileAttributes.Normal)
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Hidden: " &
            CBool(lngAttributes And IO.FileAttributes.Hidden)
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "ReadOnly: " &
            CBool(lngAttributes And IO.FileAttributes.ReadOnly)
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "System: " &
            CBool(lngAttributes And IO.FileAttributes.System)
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Temporary File: " &
            CBool(lngAttributes And IO.FileAttributes.Temporary)
        strProperties = strProperties & vbCrLf
        strProperties = strProperties & "Archive: " &
            CBool(lngAttributes And IO.FileAttributes.Archive)

        MessageBox.Show(strProperties, "Picture Viewer")
    End Sub

    Private Sub tbbShowLog_Click(sender As Object, e As EventArgs) Handles tbbShowLog.Click
        LogViewerForm.ShowDialog()
    End Sub

    Private Sub ViewPictureLogToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles ViewPictureLogToolStripMenuItem.Click
        LogViewerForm.ShowDialog()
    End Sub

    Private Sub GetFileAtttributesToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles GetFileAtttributesToolStripMenuItem.Click
        GetFileAttributes()
    End Sub

    Private Sub PrintImage(ByVal Destination As PrintDestination)

        If ofdSelectPicture.FileName = ““ Then
            MessageBox.Show(“There is no image to print.”, “Picture Viewer”,
         MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Exit Sub
        End If

        PrintDocument1.Print()

    End Sub

    Private Sub tbbPrint_Click(sender As Object, e As EventArgs) Handles tbbPrint.Click
        PrintImage(PrintDestination.Printer)

    End Sub

    Private Sub tbbPrintPreview_Click(sender As Object, e As EventArgs) Handles tbbPrintPreview.Click
        PrintImage(PrintDestination.PrintPreview)

    End Sub
End Class
